package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubRemarksDto;
import com.caimei365.user.model.dto.ClubUpdateDto;
import com.caimei365.user.model.dto.DeductionDto;
import com.caimei365.user.model.dto.JsonParamsDto;
import com.caimei365.user.model.vo.BeansHistoryVo;
import com.caimei365.user.model.vo.OperationVo;
import com.caimei365.user.model.vo.PaginationVo;
import com.caimei365.user.model.vo.RemarksVo;
import com.caimei365.user.service.ClubService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.Map;


/**
 * 机构用户API
 *
 * @author : Charles
 * @date : 2021/3/4
 */
@Api(tags = "机构用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/club")
public class ClubApi {

    private final ClubService clubService;

    /**
     * 根据用户Id查询机构资料
     * <p>
     * spi旧接口：/user/club/applicationData
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    @ApiOperation("查询机构资料")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/info")
    public ResponseJson<Map<String, Object>> getClubUserInfo(Integer userId) {
        return clubService.getClubUserInfo(userId);
    }

    /**
     * 修改机构资料
     * <p>
     * spi旧接口：/operation/modifiedData
     *
     * @param club ClubUpdateDto:{
     *             clubId                 机构ID
     *             userId                 用户ID
     *             name                   机构名称
     *             shortName                  机构简称(shortName)
     *             contractEmail          邮箱（contractEmail1）
     *             contractPhone          固定电话
     *             linkMan                联系人（linkMan1）
     *             provinceId             省Id
     *             cityId                 市Id
     *             townId                 县区Id
     *             address                地址
     *             shopPhoto              门头照(headpic)
     *             businessLicense        营业执照（businessLicenseImage）
     *             socialCreditCode       统一社会信用代码（socialCreditCode）
     *             firstClubType          一级分类：医美=1和生美=2
     *             secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *             department             医美分类下的门诊和医院则需要填写科室
     *             medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *             mainProduct            主打项目（mainpro）
     *             fax                    传真
     *             profile                公司简介
     *             }
     * @return ClubUpdateDto
     */
    @ApiOperation("更新机构资料")
    @PostMapping("/info/update")
    public ResponseJson<ClubUpdateDto> updateClubUserInfo(ClubUpdateDto club) {
        return clubService.updateClubUserInfo(club);
    }

    /**
     * 机构个人中心
     * <p>
     * spi旧接口：/personalCenter/myCentre
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    @ApiOperation("机构个人中心")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/home")
    public ResponseJson<Map<String, Object>> getClubHomeData(Integer userId) {
        return clubService.getClubHomeData(userId);
    }

    /**
     * 赠送采美豆弹窗
     */
    @ApiOperation("赠送采美豆弹窗")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/obtain/beans")
    public ResponseJson<BeansHistoryVo> beansPopUps(Integer userId) {
        if (userId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return clubService.beansPopUps(userId);
    }

    /**
     * 采美豆收支明细
     */
    @ApiOperation("采美豆收支明细")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = true, name = "year", value = "年份"),
            @ApiImplicitParam(required = true, name = "month", value = "月份"),
            @ApiImplicitParam(required = true, name = "type", value = "收支类型：1收入，2支出"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "第几页"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "一页多少条")
    })
    @GetMapping("/beans/history")
    public ResponseJson<Map<String, Object>> beansHistory(Integer userId, Integer year, Integer month, Integer type,
                                                          @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                          @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (userId == null || year == null || month == null) {
            return ResponseJson.error("参数异常",null);
        }
        return clubService.beansHistory(userId, year, month, type, pageNum, pageSize);
    }

    @ApiOperation("查看商品资料抵扣采美豆")
    @PostMapping("/archive/deduction")
    public ResponseJson archiveDeduction(DeductionDto deductionDto) {
        Integer userId = deductionDto.getUserId();
        Integer archiveId = deductionDto.getArchiveId();
        if (userId == null || archiveId == null) {
            return ResponseJson.error("参数异常");
        }
        return clubService.archiveDeduction(userId, archiveId);
    }

    @ApiOperation("机构资料备注列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "clubId", value = "机构Id"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/remarks/list")
    public ResponseJson<PaginationVo<RemarksVo>> getRemarksList(Integer clubId,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                             @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return clubService.getRemarksList(clubId, pageNum, pageSize);
    }

    @ApiOperation("机构资料备注详情")
    @ApiImplicitParam(required = true, name = "remarksId", value = "机构id")
    @GetMapping("/remarks/detail")
    public ResponseJson<RemarksVo> getRemarksDetail(Integer remarksId) {
        return clubService.getRemarksDetail(remarksId);
    }

    /**
     * @param jsonParamsDto:{
     *                     remarksId:           备注id,
     *                     机构id:               机构id,
     *                     serviceProviderId:   协销id,
     *                     remarks:             文字备注,
     *                     fileList:    [{fileName:"文件名称",ossName:"oss文件名称"},{fileName:"文件名称",ossName:"oss文件名称"}...]
     *                     imageList:   ["图片","图片",...]
     *                    }
     */
    @ApiOperation("保存机构资料备注")
    @PostMapping("/remarks/save")
    public ResponseJson saveClubRemarks(JsonParamsDto jsonParamsDto) {
        return clubService.saveClubRemarks(jsonParamsDto);
    }

    @ApiOperation("删除机构资料备注")
    @ApiImplicitParam(required = true, name = "remarksId", value = "机构id")
    @PostMapping("/remarks/delete")
    public ResponseJson deleteClubRemarks(ClubRemarksDto clubRemarksDto) {
        return clubService.deleteClubRemarks(clubRemarksDto.getRemarksId());
    }

    /**
     * 机构个人中心数据
     */
    @ApiOperation("机构个人中心数据(旧：/pcCenter/myPcCenter)")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/personal/data")
    public ResponseJson<Map<String, Object>> getPersonalData(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        return clubService.getPersonalData(userId);
    }

}
